@@ -25,7 +25,7 @@ def action_jobs_file(app, callback):
         if callback:
             data = callback(data)
             with open(filepath, mode="w") as fd:
-                json.dump(data, fd)
+                json.dump(data, fd, indent=2, sort_keys=True)
 
         return data
 
